@@ -1,7 +1,7 @@
 """
 Type annotations for workspaces-web service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/)
 
 Usage::
 
@@ -81,7 +81,7 @@ class Exceptions:
 class WorkSpacesWebClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/)
     """
 
     meta: ClientMeta
@@ -92,7 +92,7 @@ class WorkSpacesWebClient(BaseClient):
         WorkSpacesWebClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#exceptions)
         """
 
     def associate_browser_settings(
@@ -102,7 +102,7 @@ class WorkSpacesWebClient(BaseClient):
         Associates a browser settings resource with a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.associate_browser_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#associate_browser_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#associate_browser_settings)
         """
 
     def associate_network_settings(
@@ -112,7 +112,7 @@ class WorkSpacesWebClient(BaseClient):
         Associates a network settings resource with a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.associate_network_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#associate_network_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#associate_network_settings)
         """
 
     def associate_trust_store(
@@ -122,7 +122,7 @@ class WorkSpacesWebClient(BaseClient):
         Associates a trust store with a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.associate_trust_store)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#associate_trust_store)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#associate_trust_store)
         """
 
     def associate_user_settings(
@@ -132,7 +132,7 @@ class WorkSpacesWebClient(BaseClient):
         Associates a user settings resource with a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.associate_user_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#associate_user_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#associate_user_settings)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -140,7 +140,7 @@ class WorkSpacesWebClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#can_paginate)
         """
 
     def create_browser_settings(
@@ -156,7 +156,7 @@ class WorkSpacesWebClient(BaseClient):
         Creates a browser settings resource that can be associated with a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.create_browser_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#create_browser_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#create_browser_settings)
         """
 
     def create_identity_provider(
@@ -172,7 +172,7 @@ class WorkSpacesWebClient(BaseClient):
         Creates an identity provider resource that is then associated with a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.create_identity_provider)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#create_identity_provider)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#create_identity_provider)
         """
 
     def create_network_settings(
@@ -188,7 +188,7 @@ class WorkSpacesWebClient(BaseClient):
         Creates a network settings resource that can be associated with a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.create_network_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#create_network_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#create_network_settings)
         """
 
     def create_portal(
@@ -204,7 +204,7 @@ class WorkSpacesWebClient(BaseClient):
         Creates a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.create_portal)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#create_portal)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#create_portal)
         """
 
     def create_trust_store(
@@ -218,7 +218,7 @@ class WorkSpacesWebClient(BaseClient):
         Creates a trust store that can be associated with a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.create_trust_store)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#create_trust_store)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#create_trust_store)
         """
 
     def create_user_settings(
@@ -236,7 +236,7 @@ class WorkSpacesWebClient(BaseClient):
         Creates a user settings resource that can be associated with a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.create_user_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#create_user_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#create_user_settings)
         """
 
     def delete_browser_settings(self, *, browserSettingsArn: str) -> Dict[str, Any]:
@@ -244,7 +244,7 @@ class WorkSpacesWebClient(BaseClient):
         Deletes browser settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.delete_browser_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#delete_browser_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_browser_settings)
         """
 
     def delete_identity_provider(self, *, identityProviderArn: str) -> Dict[str, Any]:
@@ -252,7 +252,7 @@ class WorkSpacesWebClient(BaseClient):
         Deletes the identity provider.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.delete_identity_provider)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#delete_identity_provider)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_identity_provider)
         """
 
     def delete_network_settings(self, *, networkSettingsArn: str) -> Dict[str, Any]:
@@ -260,7 +260,7 @@ class WorkSpacesWebClient(BaseClient):
         Deletes network settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.delete_network_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#delete_network_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_network_settings)
         """
 
     def delete_portal(self, *, portalArn: str) -> Dict[str, Any]:
@@ -268,7 +268,7 @@ class WorkSpacesWebClient(BaseClient):
         Deletes a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.delete_portal)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#delete_portal)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_portal)
         """
 
     def delete_trust_store(self, *, trustStoreArn: str) -> Dict[str, Any]:
@@ -276,7 +276,7 @@ class WorkSpacesWebClient(BaseClient):
         Deletes the trust store.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.delete_trust_store)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#delete_trust_store)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_trust_store)
         """
 
     def delete_user_settings(self, *, userSettingsArn: str) -> Dict[str, Any]:
@@ -284,7 +284,7 @@ class WorkSpacesWebClient(BaseClient):
         Deletes user settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.delete_user_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#delete_user_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#delete_user_settings)
         """
 
     def disassociate_browser_settings(self, *, portalArn: str) -> Dict[str, Any]:
@@ -292,7 +292,7 @@ class WorkSpacesWebClient(BaseClient):
         Disassociates browser settings from a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.disassociate_browser_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#disassociate_browser_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_browser_settings)
         """
 
     def disassociate_network_settings(self, *, portalArn: str) -> Dict[str, Any]:
@@ -300,7 +300,7 @@ class WorkSpacesWebClient(BaseClient):
         Disassociates network settings from a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.disassociate_network_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#disassociate_network_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_network_settings)
         """
 
     def disassociate_trust_store(self, *, portalArn: str) -> Dict[str, Any]:
@@ -308,7 +308,7 @@ class WorkSpacesWebClient(BaseClient):
         Disassociates a trust store from a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.disassociate_trust_store)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#disassociate_trust_store)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_trust_store)
         """
 
     def disassociate_user_settings(self, *, portalArn: str) -> Dict[str, Any]:
@@ -316,7 +316,7 @@ class WorkSpacesWebClient(BaseClient):
         Disassociates user settings from a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.disassociate_user_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#disassociate_user_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#disassociate_user_settings)
         """
 
     def generate_presigned_url(
@@ -330,7 +330,7 @@ class WorkSpacesWebClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#generate_presigned_url)
         """
 
     def get_browser_settings(self, *, browserSettingsArn: str) -> GetBrowserSettingsResponseTypeDef:
@@ -338,7 +338,7 @@ class WorkSpacesWebClient(BaseClient):
         Gets browser settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_browser_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#get_browser_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_browser_settings)
         """
 
     def get_identity_provider(
@@ -348,7 +348,7 @@ class WorkSpacesWebClient(BaseClient):
         Gets the identity provider.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_identity_provider)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#get_identity_provider)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_identity_provider)
         """
 
     def get_network_settings(self, *, networkSettingsArn: str) -> GetNetworkSettingsResponseTypeDef:
@@ -356,7 +356,7 @@ class WorkSpacesWebClient(BaseClient):
         Gets the network settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_network_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#get_network_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_network_settings)
         """
 
     def get_portal(self, *, portalArn: str) -> GetPortalResponseTypeDef:
@@ -364,7 +364,7 @@ class WorkSpacesWebClient(BaseClient):
         Gets the web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_portal)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#get_portal)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_portal)
         """
 
     def get_portal_service_provider_metadata(
@@ -374,7 +374,7 @@ class WorkSpacesWebClient(BaseClient):
         Gets the service provider metadata.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_portal_service_provider_metadata)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#get_portal_service_provider_metadata)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_portal_service_provider_metadata)
         """
 
     def get_trust_store(self, *, trustStoreArn: str) -> GetTrustStoreResponseTypeDef:
@@ -382,7 +382,7 @@ class WorkSpacesWebClient(BaseClient):
         Gets the trust store.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_trust_store)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#get_trust_store)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_trust_store)
         """
 
     def get_trust_store_certificate(
@@ -392,7 +392,7 @@ class WorkSpacesWebClient(BaseClient):
         Gets the trust store certificate.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_trust_store_certificate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#get_trust_store_certificate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_trust_store_certificate)
         """
 
     def get_user_settings(self, *, userSettingsArn: str) -> GetUserSettingsResponseTypeDef:
@@ -400,7 +400,7 @@ class WorkSpacesWebClient(BaseClient):
         Gets user settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.get_user_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#get_user_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#get_user_settings)
         """
 
     def list_browser_settings(
@@ -410,7 +410,7 @@ class WorkSpacesWebClient(BaseClient):
         Retrieves a list of browser settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_browser_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#list_browser_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_browser_settings)
         """
 
     def list_identity_providers(
@@ -420,7 +420,7 @@ class WorkSpacesWebClient(BaseClient):
         Retrieves a list of identity providers for a specific web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_identity_providers)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#list_identity_providers)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_identity_providers)
         """
 
     def list_network_settings(
@@ -430,7 +430,7 @@ class WorkSpacesWebClient(BaseClient):
         Retrieves a list of network settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_network_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#list_network_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_network_settings)
         """
 
     def list_portals(
@@ -440,7 +440,7 @@ class WorkSpacesWebClient(BaseClient):
         Retrieves a list or web portals.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_portals)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#list_portals)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_portals)
         """
 
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
@@ -448,7 +448,7 @@ class WorkSpacesWebClient(BaseClient):
         Retrieves a list of tags for a resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#list_tags_for_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_tags_for_resource)
         """
 
     def list_trust_store_certificates(
@@ -458,7 +458,7 @@ class WorkSpacesWebClient(BaseClient):
         Retrieves a list of trust store certificates.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_trust_store_certificates)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#list_trust_store_certificates)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_trust_store_certificates)
         """
 
     def list_trust_stores(
@@ -468,7 +468,7 @@ class WorkSpacesWebClient(BaseClient):
         Retrieves a list of trust stores.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_trust_stores)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#list_trust_stores)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_trust_stores)
         """
 
     def list_user_settings(
@@ -478,7 +478,7 @@ class WorkSpacesWebClient(BaseClient):
         Retrieves a list of user settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.list_user_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#list_user_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#list_user_settings)
         """
 
     def tag_resource(
@@ -488,7 +488,7 @@ class WorkSpacesWebClient(BaseClient):
         Adds or overwrites one or more tags for the specified resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#tag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#tag_resource)
         """
 
     def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
@@ -496,7 +496,7 @@ class WorkSpacesWebClient(BaseClient):
         Removes one or more tags from the specified resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#untag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#untag_resource)
         """
 
     def update_browser_settings(
@@ -506,7 +506,7 @@ class WorkSpacesWebClient(BaseClient):
         Updates browser settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.update_browser_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#update_browser_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#update_browser_settings)
         """
 
     def update_identity_provider(
@@ -522,7 +522,7 @@ class WorkSpacesWebClient(BaseClient):
         Updates the identity provider.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.update_identity_provider)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#update_identity_provider)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#update_identity_provider)
         """
 
     def update_network_settings(
@@ -538,7 +538,7 @@ class WorkSpacesWebClient(BaseClient):
         Updates network settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.update_network_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#update_network_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#update_network_settings)
         """
 
     def update_portal(
@@ -548,7 +548,7 @@ class WorkSpacesWebClient(BaseClient):
         Updates a web portal.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.update_portal)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#update_portal)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#update_portal)
         """
 
     def update_trust_store(
@@ -563,7 +563,7 @@ class WorkSpacesWebClient(BaseClient):
         Updates the trust store.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.update_trust_store)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#update_trust_store)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#update_trust_store)
         """
 
     def update_user_settings(
@@ -581,5 +581,5 @@ class WorkSpacesWebClient(BaseClient):
         Updates the user settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workspaces-web.html#WorkSpacesWeb.Client.update_user_settings)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client.html#update_user_settings)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/client/#update_user_settings)
         """
