@@ -1,7 +1,7 @@
 """
 Type annotations for workspaces-web service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/literals/)
 
 Usage::
 
@@ -28,6 +28,7 @@ __all__ = (
     "WorkSpacesWebServiceName",
     "ServiceName",
     "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -157,6 +158,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -354,3 +356,4 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+RegionName = Literal["eu-west-1", "us-east-1", "us-west-2"]
