@@ -1,7 +1,7 @@
 """
 Type annotations for workspaces-web service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/type_defs/)
 
 Usage::
 
@@ -196,52 +196,80 @@ AssociateUserSettingsResponseTypeDef = TypedDict(
 BrowserSettingsSummaryTypeDef = TypedDict(
     "BrowserSettingsSummaryTypeDef",
     {
-        "browserSettingsArn": NotRequired[str],
+        "browserSettingsArn": str,
     },
+    total=False,
 )
 
-BrowserSettingsTypeDef = TypedDict(
-    "BrowserSettingsTypeDef",
+_RequiredBrowserSettingsTypeDef = TypedDict(
+    "_RequiredBrowserSettingsTypeDef",
     {
         "browserSettingsArn": str,
-        "associatedPortalArns": NotRequired[List[str]],
-        "browserPolicy": NotRequired[str],
     },
 )
+_OptionalBrowserSettingsTypeDef = TypedDict(
+    "_OptionalBrowserSettingsTypeDef",
+    {
+        "associatedPortalArns": List[str],
+        "browserPolicy": str,
+    },
+    total=False,
+)
+
+
+class BrowserSettingsTypeDef(_RequiredBrowserSettingsTypeDef, _OptionalBrowserSettingsTypeDef):
+    pass
+
 
 CertificateSummaryTypeDef = TypedDict(
     "CertificateSummaryTypeDef",
     {
-        "issuer": NotRequired[str],
-        "notValidAfter": NotRequired[datetime],
-        "notValidBefore": NotRequired[datetime],
-        "subject": NotRequired[str],
-        "thumbprint": NotRequired[str],
+        "issuer": str,
+        "notValidAfter": datetime,
+        "notValidBefore": datetime,
+        "subject": str,
+        "thumbprint": str,
     },
+    total=False,
 )
 
 CertificateTypeDef = TypedDict(
     "CertificateTypeDef",
     {
-        "body": NotRequired[bytes],
-        "issuer": NotRequired[str],
-        "notValidAfter": NotRequired[datetime],
-        "notValidBefore": NotRequired[datetime],
-        "subject": NotRequired[str],
-        "thumbprint": NotRequired[str],
+        "body": bytes,
+        "issuer": str,
+        "notValidAfter": datetime,
+        "notValidBefore": datetime,
+        "subject": str,
+        "thumbprint": str,
     },
+    total=False,
 )
 
-CreateBrowserSettingsRequestRequestTypeDef = TypedDict(
-    "CreateBrowserSettingsRequestRequestTypeDef",
+_RequiredCreateBrowserSettingsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateBrowserSettingsRequestRequestTypeDef",
     {
         "browserPolicy": str,
-        "additionalEncryptionContext": NotRequired[Mapping[str, str]],
-        "clientToken": NotRequired[str],
-        "customerManagedKey": NotRequired[str],
-        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateBrowserSettingsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateBrowserSettingsRequestRequestTypeDef",
+    {
+        "additionalEncryptionContext": Mapping[str, str],
+        "clientToken": str,
+        "customerManagedKey": str,
+        "tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateBrowserSettingsRequestRequestTypeDef(
+    _RequiredCreateBrowserSettingsRequestRequestTypeDef,
+    _OptionalCreateBrowserSettingsRequestRequestTypeDef,
+):
+    pass
+
 
 CreateBrowserSettingsResponseTypeDef = TypedDict(
     "CreateBrowserSettingsResponseTypeDef",
@@ -251,16 +279,30 @@ CreateBrowserSettingsResponseTypeDef = TypedDict(
     },
 )
 
-CreateIdentityProviderRequestRequestTypeDef = TypedDict(
-    "CreateIdentityProviderRequestRequestTypeDef",
+_RequiredCreateIdentityProviderRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateIdentityProviderRequestRequestTypeDef",
     {
         "identityProviderDetails": Mapping[str, str],
         "identityProviderName": str,
         "identityProviderType": IdentityProviderTypeType,
         "portalArn": str,
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalCreateIdentityProviderRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateIdentityProviderRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class CreateIdentityProviderRequestRequestTypeDef(
+    _RequiredCreateIdentityProviderRequestRequestTypeDef,
+    _OptionalCreateIdentityProviderRequestRequestTypeDef,
+):
+    pass
+
 
 CreateIdentityProviderResponseTypeDef = TypedDict(
     "CreateIdentityProviderResponseTypeDef",
@@ -270,16 +312,30 @@ CreateIdentityProviderResponseTypeDef = TypedDict(
     },
 )
 
-CreateNetworkSettingsRequestRequestTypeDef = TypedDict(
-    "CreateNetworkSettingsRequestRequestTypeDef",
+_RequiredCreateNetworkSettingsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateNetworkSettingsRequestRequestTypeDef",
     {
         "securityGroupIds": Sequence[str],
         "subnetIds": Sequence[str],
         "vpcId": str,
-        "clientToken": NotRequired[str],
-        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateNetworkSettingsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateNetworkSettingsRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateNetworkSettingsRequestRequestTypeDef(
+    _RequiredCreateNetworkSettingsRequestRequestTypeDef,
+    _OptionalCreateNetworkSettingsRequestRequestTypeDef,
+):
+    pass
+
 
 CreateNetworkSettingsResponseTypeDef = TypedDict(
     "CreateNetworkSettingsResponseTypeDef",
@@ -292,12 +348,13 @@ CreateNetworkSettingsResponseTypeDef = TypedDict(
 CreatePortalRequestRequestTypeDef = TypedDict(
     "CreatePortalRequestRequestTypeDef",
     {
-        "additionalEncryptionContext": NotRequired[Mapping[str, str]],
-        "clientToken": NotRequired[str],
-        "customerManagedKey": NotRequired[str],
-        "displayName": NotRequired[str],
-        "tags": NotRequired[Sequence["TagTypeDef"]],
+        "additionalEncryptionContext": Mapping[str, str],
+        "clientToken": str,
+        "customerManagedKey": str,
+        "displayName": str,
+        "tags": Sequence["TagTypeDef"],
     },
+    total=False,
 )
 
 CreatePortalResponseTypeDef = TypedDict(
@@ -309,14 +366,27 @@ CreatePortalResponseTypeDef = TypedDict(
     },
 )
 
-CreateTrustStoreRequestRequestTypeDef = TypedDict(
-    "CreateTrustStoreRequestRequestTypeDef",
+_RequiredCreateTrustStoreRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateTrustStoreRequestRequestTypeDef",
     {
         "certificateList": Sequence[Union[bytes, IO[bytes], StreamingBody]],
-        "clientToken": NotRequired[str],
-        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateTrustStoreRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateTrustStoreRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateTrustStoreRequestRequestTypeDef(
+    _RequiredCreateTrustStoreRequestRequestTypeDef, _OptionalCreateTrustStoreRequestRequestTypeDef
+):
+    pass
+
 
 CreateTrustStoreResponseTypeDef = TypedDict(
     "CreateTrustStoreResponseTypeDef",
@@ -326,18 +396,32 @@ CreateTrustStoreResponseTypeDef = TypedDict(
     },
 )
 
-CreateUserSettingsRequestRequestTypeDef = TypedDict(
-    "CreateUserSettingsRequestRequestTypeDef",
+_RequiredCreateUserSettingsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateUserSettingsRequestRequestTypeDef",
     {
         "copyAllowed": EnabledTypeType,
         "downloadAllowed": EnabledTypeType,
         "pasteAllowed": EnabledTypeType,
         "printAllowed": EnabledTypeType,
         "uploadAllowed": EnabledTypeType,
-        "clientToken": NotRequired[str],
-        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateUserSettingsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateUserSettingsRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateUserSettingsRequestRequestTypeDef(
+    _RequiredCreateUserSettingsRequestRequestTypeDef,
+    _OptionalCreateUserSettingsRequestRequestTypeDef,
+):
+    pass
+
 
 CreateUserSettingsResponseTypeDef = TypedDict(
     "CreateUserSettingsResponseTypeDef",
@@ -543,28 +627,41 @@ GetUserSettingsResponseTypeDef = TypedDict(
 IdentityProviderSummaryTypeDef = TypedDict(
     "IdentityProviderSummaryTypeDef",
     {
-        "identityProviderArn": NotRequired[str],
-        "identityProviderName": NotRequired[str],
-        "identityProviderType": NotRequired[IdentityProviderTypeType],
+        "identityProviderArn": str,
+        "identityProviderName": str,
+        "identityProviderType": IdentityProviderTypeType,
     },
+    total=False,
 )
 
-IdentityProviderTypeDef = TypedDict(
-    "IdentityProviderTypeDef",
+_RequiredIdentityProviderTypeDef = TypedDict(
+    "_RequiredIdentityProviderTypeDef",
     {
         "identityProviderArn": str,
-        "identityProviderDetails": NotRequired[Dict[str, str]],
-        "identityProviderName": NotRequired[str],
-        "identityProviderType": NotRequired[IdentityProviderTypeType],
     },
 )
+_OptionalIdentityProviderTypeDef = TypedDict(
+    "_OptionalIdentityProviderTypeDef",
+    {
+        "identityProviderDetails": Dict[str, str],
+        "identityProviderName": str,
+        "identityProviderType": IdentityProviderTypeType,
+    },
+    total=False,
+)
+
+
+class IdentityProviderTypeDef(_RequiredIdentityProviderTypeDef, _OptionalIdentityProviderTypeDef):
+    pass
+
 
 ListBrowserSettingsRequestRequestTypeDef = TypedDict(
     "ListBrowserSettingsRequestRequestTypeDef",
     {
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListBrowserSettingsResponseTypeDef = TypedDict(
@@ -576,14 +673,28 @@ ListBrowserSettingsResponseTypeDef = TypedDict(
     },
 )
 
-ListIdentityProvidersRequestRequestTypeDef = TypedDict(
-    "ListIdentityProvidersRequestRequestTypeDef",
+_RequiredListIdentityProvidersRequestRequestTypeDef = TypedDict(
+    "_RequiredListIdentityProvidersRequestRequestTypeDef",
     {
         "portalArn": str,
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalListIdentityProvidersRequestRequestTypeDef = TypedDict(
+    "_OptionalListIdentityProvidersRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListIdentityProvidersRequestRequestTypeDef(
+    _RequiredListIdentityProvidersRequestRequestTypeDef,
+    _OptionalListIdentityProvidersRequestRequestTypeDef,
+):
+    pass
+
 
 ListIdentityProvidersResponseTypeDef = TypedDict(
     "ListIdentityProvidersResponseTypeDef",
@@ -597,9 +708,10 @@ ListIdentityProvidersResponseTypeDef = TypedDict(
 ListNetworkSettingsRequestRequestTypeDef = TypedDict(
     "ListNetworkSettingsRequestRequestTypeDef",
     {
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListNetworkSettingsResponseTypeDef = TypedDict(
@@ -614,9 +726,10 @@ ListNetworkSettingsResponseTypeDef = TypedDict(
 ListPortalsRequestRequestTypeDef = TypedDict(
     "ListPortalsRequestRequestTypeDef",
     {
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListPortalsResponseTypeDef = TypedDict(
@@ -643,14 +756,28 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-ListTrustStoreCertificatesRequestRequestTypeDef = TypedDict(
-    "ListTrustStoreCertificatesRequestRequestTypeDef",
+_RequiredListTrustStoreCertificatesRequestRequestTypeDef = TypedDict(
+    "_RequiredListTrustStoreCertificatesRequestRequestTypeDef",
     {
         "trustStoreArn": str,
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalListTrustStoreCertificatesRequestRequestTypeDef = TypedDict(
+    "_OptionalListTrustStoreCertificatesRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListTrustStoreCertificatesRequestRequestTypeDef(
+    _RequiredListTrustStoreCertificatesRequestRequestTypeDef,
+    _OptionalListTrustStoreCertificatesRequestRequestTypeDef,
+):
+    pass
+
 
 ListTrustStoreCertificatesResponseTypeDef = TypedDict(
     "ListTrustStoreCertificatesResponseTypeDef",
@@ -665,9 +792,10 @@ ListTrustStoreCertificatesResponseTypeDef = TypedDict(
 ListTrustStoresRequestRequestTypeDef = TypedDict(
     "ListTrustStoresRequestRequestTypeDef",
     {
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListTrustStoresResponseTypeDef = TypedDict(
@@ -682,9 +810,10 @@ ListTrustStoresResponseTypeDef = TypedDict(
 ListUserSettingsRequestRequestTypeDef = TypedDict(
     "ListUserSettingsRequestRequestTypeDef",
     {
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListUserSettingsResponseTypeDef = TypedDict(
@@ -699,55 +828,69 @@ ListUserSettingsResponseTypeDef = TypedDict(
 NetworkSettingsSummaryTypeDef = TypedDict(
     "NetworkSettingsSummaryTypeDef",
     {
-        "networkSettingsArn": NotRequired[str],
-        "vpcId": NotRequired[str],
+        "networkSettingsArn": str,
+        "vpcId": str,
     },
+    total=False,
 )
 
-NetworkSettingsTypeDef = TypedDict(
-    "NetworkSettingsTypeDef",
+_RequiredNetworkSettingsTypeDef = TypedDict(
+    "_RequiredNetworkSettingsTypeDef",
     {
         "networkSettingsArn": str,
-        "associatedPortalArns": NotRequired[List[str]],
-        "securityGroupIds": NotRequired[List[str]],
-        "subnetIds": NotRequired[List[str]],
-        "vpcId": NotRequired[str],
     },
 )
+_OptionalNetworkSettingsTypeDef = TypedDict(
+    "_OptionalNetworkSettingsTypeDef",
+    {
+        "associatedPortalArns": List[str],
+        "securityGroupIds": List[str],
+        "subnetIds": List[str],
+        "vpcId": str,
+    },
+    total=False,
+)
+
+
+class NetworkSettingsTypeDef(_RequiredNetworkSettingsTypeDef, _OptionalNetworkSettingsTypeDef):
+    pass
+
 
 PortalSummaryTypeDef = TypedDict(
     "PortalSummaryTypeDef",
     {
-        "browserSettingsArn": NotRequired[str],
-        "browserType": NotRequired[Literal["Chrome"]],
-        "creationDate": NotRequired[datetime],
-        "displayName": NotRequired[str],
-        "networkSettingsArn": NotRequired[str],
-        "portalArn": NotRequired[str],
-        "portalEndpoint": NotRequired[str],
-        "portalStatus": NotRequired[PortalStatusType],
-        "rendererType": NotRequired[Literal["AppStream"]],
-        "trustStoreArn": NotRequired[str],
-        "userSettingsArn": NotRequired[str],
+        "browserSettingsArn": str,
+        "browserType": Literal["Chrome"],
+        "creationDate": datetime,
+        "displayName": str,
+        "networkSettingsArn": str,
+        "portalArn": str,
+        "portalEndpoint": str,
+        "portalStatus": PortalStatusType,
+        "rendererType": Literal["AppStream"],
+        "trustStoreArn": str,
+        "userSettingsArn": str,
     },
+    total=False,
 )
 
 PortalTypeDef = TypedDict(
     "PortalTypeDef",
     {
-        "browserSettingsArn": NotRequired[str],
-        "browserType": NotRequired[Literal["Chrome"]],
-        "creationDate": NotRequired[datetime],
-        "displayName": NotRequired[str],
-        "networkSettingsArn": NotRequired[str],
-        "portalArn": NotRequired[str],
-        "portalEndpoint": NotRequired[str],
-        "portalStatus": NotRequired[PortalStatusType],
-        "rendererType": NotRequired[Literal["AppStream"]],
-        "statusReason": NotRequired[str],
-        "trustStoreArn": NotRequired[str],
-        "userSettingsArn": NotRequired[str],
+        "browserSettingsArn": str,
+        "browserType": Literal["Chrome"],
+        "creationDate": datetime,
+        "displayName": str,
+        "networkSettingsArn": str,
+        "portalArn": str,
+        "portalEndpoint": str,
+        "portalStatus": PortalStatusType,
+        "rendererType": Literal["AppStream"],
+        "statusReason": str,
+        "trustStoreArn": str,
+        "userSettingsArn": str,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -761,14 +904,27 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
+_RequiredTagResourceRequestRequestTypeDef = TypedDict(
+    "_RequiredTagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "tags": Sequence["TagTypeDef"],
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalTagResourceRequestRequestTypeDef = TypedDict(
+    "_OptionalTagResourceRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class TagResourceRequestRequestTypeDef(
+    _RequiredTagResourceRequestRequestTypeDef, _OptionalTagResourceRequestRequestTypeDef
+):
+    pass
+
 
 TagTypeDef = TypedDict(
     "TagTypeDef",
@@ -781,16 +937,18 @@ TagTypeDef = TypedDict(
 TrustStoreSummaryTypeDef = TypedDict(
     "TrustStoreSummaryTypeDef",
     {
-        "trustStoreArn": NotRequired[str],
+        "trustStoreArn": str,
     },
+    total=False,
 )
 
 TrustStoreTypeDef = TypedDict(
     "TrustStoreTypeDef",
     {
-        "associatedPortalArns": NotRequired[List[str]],
-        "trustStoreArn": NotRequired[str],
+        "associatedPortalArns": List[str],
+        "trustStoreArn": str,
     },
+    total=False,
 )
 
 UntagResourceRequestRequestTypeDef = TypedDict(
@@ -801,14 +959,28 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateBrowserSettingsRequestRequestTypeDef = TypedDict(
-    "UpdateBrowserSettingsRequestRequestTypeDef",
+_RequiredUpdateBrowserSettingsRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateBrowserSettingsRequestRequestTypeDef",
     {
         "browserSettingsArn": str,
-        "browserPolicy": NotRequired[str],
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalUpdateBrowserSettingsRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateBrowserSettingsRequestRequestTypeDef",
+    {
+        "browserPolicy": str,
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateBrowserSettingsRequestRequestTypeDef(
+    _RequiredUpdateBrowserSettingsRequestRequestTypeDef,
+    _OptionalUpdateBrowserSettingsRequestRequestTypeDef,
+):
+    pass
+
 
 UpdateBrowserSettingsResponseTypeDef = TypedDict(
     "UpdateBrowserSettingsResponseTypeDef",
@@ -818,16 +990,30 @@ UpdateBrowserSettingsResponseTypeDef = TypedDict(
     },
 )
 
-UpdateIdentityProviderRequestRequestTypeDef = TypedDict(
-    "UpdateIdentityProviderRequestRequestTypeDef",
+_RequiredUpdateIdentityProviderRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateIdentityProviderRequestRequestTypeDef",
     {
         "identityProviderArn": str,
-        "clientToken": NotRequired[str],
-        "identityProviderDetails": NotRequired[Mapping[str, str]],
-        "identityProviderName": NotRequired[str],
-        "identityProviderType": NotRequired[IdentityProviderTypeType],
     },
 )
+_OptionalUpdateIdentityProviderRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateIdentityProviderRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "identityProviderDetails": Mapping[str, str],
+        "identityProviderName": str,
+        "identityProviderType": IdentityProviderTypeType,
+    },
+    total=False,
+)
+
+
+class UpdateIdentityProviderRequestRequestTypeDef(
+    _RequiredUpdateIdentityProviderRequestRequestTypeDef,
+    _OptionalUpdateIdentityProviderRequestRequestTypeDef,
+):
+    pass
+
 
 UpdateIdentityProviderResponseTypeDef = TypedDict(
     "UpdateIdentityProviderResponseTypeDef",
@@ -837,16 +1023,30 @@ UpdateIdentityProviderResponseTypeDef = TypedDict(
     },
 )
 
-UpdateNetworkSettingsRequestRequestTypeDef = TypedDict(
-    "UpdateNetworkSettingsRequestRequestTypeDef",
+_RequiredUpdateNetworkSettingsRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateNetworkSettingsRequestRequestTypeDef",
     {
         "networkSettingsArn": str,
-        "clientToken": NotRequired[str],
-        "securityGroupIds": NotRequired[Sequence[str]],
-        "subnetIds": NotRequired[Sequence[str]],
-        "vpcId": NotRequired[str],
     },
 )
+_OptionalUpdateNetworkSettingsRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateNetworkSettingsRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "securityGroupIds": Sequence[str],
+        "subnetIds": Sequence[str],
+        "vpcId": str,
+    },
+    total=False,
+)
+
+
+class UpdateNetworkSettingsRequestRequestTypeDef(
+    _RequiredUpdateNetworkSettingsRequestRequestTypeDef,
+    _OptionalUpdateNetworkSettingsRequestRequestTypeDef,
+):
+    pass
+
 
 UpdateNetworkSettingsResponseTypeDef = TypedDict(
     "UpdateNetworkSettingsResponseTypeDef",
@@ -856,13 +1056,26 @@ UpdateNetworkSettingsResponseTypeDef = TypedDict(
     },
 )
 
-UpdatePortalRequestRequestTypeDef = TypedDict(
-    "UpdatePortalRequestRequestTypeDef",
+_RequiredUpdatePortalRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdatePortalRequestRequestTypeDef",
     {
         "portalArn": str,
-        "displayName": NotRequired[str],
     },
 )
+_OptionalUpdatePortalRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdatePortalRequestRequestTypeDef",
+    {
+        "displayName": str,
+    },
+    total=False,
+)
+
+
+class UpdatePortalRequestRequestTypeDef(
+    _RequiredUpdatePortalRequestRequestTypeDef, _OptionalUpdatePortalRequestRequestTypeDef
+):
+    pass
+
 
 UpdatePortalResponseTypeDef = TypedDict(
     "UpdatePortalResponseTypeDef",
@@ -872,15 +1085,28 @@ UpdatePortalResponseTypeDef = TypedDict(
     },
 )
 
-UpdateTrustStoreRequestRequestTypeDef = TypedDict(
-    "UpdateTrustStoreRequestRequestTypeDef",
+_RequiredUpdateTrustStoreRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateTrustStoreRequestRequestTypeDef",
     {
         "trustStoreArn": str,
-        "certificatesToAdd": NotRequired[Sequence[Union[bytes, IO[bytes], StreamingBody]]],
-        "certificatesToDelete": NotRequired[Sequence[str]],
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalUpdateTrustStoreRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateTrustStoreRequestRequestTypeDef",
+    {
+        "certificatesToAdd": Sequence[Union[bytes, IO[bytes], StreamingBody]],
+        "certificatesToDelete": Sequence[str],
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateTrustStoreRequestRequestTypeDef(
+    _RequiredUpdateTrustStoreRequestRequestTypeDef, _OptionalUpdateTrustStoreRequestRequestTypeDef
+):
+    pass
+
 
 UpdateTrustStoreResponseTypeDef = TypedDict(
     "UpdateTrustStoreResponseTypeDef",
@@ -890,18 +1116,32 @@ UpdateTrustStoreResponseTypeDef = TypedDict(
     },
 )
 
-UpdateUserSettingsRequestRequestTypeDef = TypedDict(
-    "UpdateUserSettingsRequestRequestTypeDef",
+_RequiredUpdateUserSettingsRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateUserSettingsRequestRequestTypeDef",
     {
         "userSettingsArn": str,
-        "clientToken": NotRequired[str],
-        "copyAllowed": NotRequired[EnabledTypeType],
-        "downloadAllowed": NotRequired[EnabledTypeType],
-        "pasteAllowed": NotRequired[EnabledTypeType],
-        "printAllowed": NotRequired[EnabledTypeType],
-        "uploadAllowed": NotRequired[EnabledTypeType],
     },
 )
+_OptionalUpdateUserSettingsRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateUserSettingsRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "copyAllowed": EnabledTypeType,
+        "downloadAllowed": EnabledTypeType,
+        "pasteAllowed": EnabledTypeType,
+        "printAllowed": EnabledTypeType,
+        "uploadAllowed": EnabledTypeType,
+    },
+    total=False,
+)
+
+
+class UpdateUserSettingsRequestRequestTypeDef(
+    _RequiredUpdateUserSettingsRequestRequestTypeDef,
+    _OptionalUpdateUserSettingsRequestRequestTypeDef,
+):
+    pass
+
 
 UpdateUserSettingsResponseTypeDef = TypedDict(
     "UpdateUserSettingsResponseTypeDef",
@@ -914,24 +1154,35 @@ UpdateUserSettingsResponseTypeDef = TypedDict(
 UserSettingsSummaryTypeDef = TypedDict(
     "UserSettingsSummaryTypeDef",
     {
-        "copyAllowed": NotRequired[EnabledTypeType],
-        "downloadAllowed": NotRequired[EnabledTypeType],
-        "pasteAllowed": NotRequired[EnabledTypeType],
-        "printAllowed": NotRequired[EnabledTypeType],
-        "uploadAllowed": NotRequired[EnabledTypeType],
-        "userSettingsArn": NotRequired[str],
+        "copyAllowed": EnabledTypeType,
+        "downloadAllowed": EnabledTypeType,
+        "pasteAllowed": EnabledTypeType,
+        "printAllowed": EnabledTypeType,
+        "uploadAllowed": EnabledTypeType,
+        "userSettingsArn": str,
     },
+    total=False,
 )
 
-UserSettingsTypeDef = TypedDict(
-    "UserSettingsTypeDef",
+_RequiredUserSettingsTypeDef = TypedDict(
+    "_RequiredUserSettingsTypeDef",
     {
         "userSettingsArn": str,
-        "associatedPortalArns": NotRequired[List[str]],
-        "copyAllowed": NotRequired[EnabledTypeType],
-        "downloadAllowed": NotRequired[EnabledTypeType],
-        "pasteAllowed": NotRequired[EnabledTypeType],
-        "printAllowed": NotRequired[EnabledTypeType],
-        "uploadAllowed": NotRequired[EnabledTypeType],
     },
 )
+_OptionalUserSettingsTypeDef = TypedDict(
+    "_OptionalUserSettingsTypeDef",
+    {
+        "associatedPortalArns": List[str],
+        "copyAllowed": EnabledTypeType,
+        "downloadAllowed": EnabledTypeType,
+        "pasteAllowed": EnabledTypeType,
+        "printAllowed": EnabledTypeType,
+        "uploadAllowed": EnabledTypeType,
+    },
+    total=False,
+)
+
+
+class UserSettingsTypeDef(_RequiredUserSettingsTypeDef, _OptionalUserSettingsTypeDef):
+    pass
